function convdata (prefix, M, start_snr)
%CONVDATA   Convert data from C output to Matlab .M file.

%   Ling Li, Caltech
%   05/27/2001

if nargin < 2,
    M = 100;
end
if nargin < 1,
    prefix = 'bo';
end

iters = [1, 2, 4, 6, 8, 12, 16];
snrs = (0:6) / 2;
niters = length(iters);
nsnrs = length(snrs);

% pi_cens: (bin, snr, ite) centers of bins in the histgram
% pi_pdfs: (bin, snr, ite) high (probability densities) of bins in the histgram
% pi_errs: (snr, ite) BER in pi distribution
% pi_vars: (snr, ite) variances in pi distribution
% pi_exps: (snr, ite) expectations (means) in pi distribution
pi_cens = zeros(M, nsnrs, niters);
pi_pdfs = zeros(M, nsnrs, niters);
pi_errs = zeros(nsnrs, niters);
pi_vars = zeros(nsnrs, niters);
pi_exps = zeros(nsnrs, niters);

if nargin > 2,
    fn = [prefix '_data'];
    disp(['Loading ' fn]);
    eval(['load ' fn]);
    start_idx = find(snrs == start_snr)
else
    start_idx = 1;
end

for snr = start_idx:nsnrs,
    s = snrs(snr);
    for ite = 1:niters,
        fn = [prefix '_' int2str(floor(s)) '_' int2str(mod(s*10, 10)) ... 
                '_' int2str(iters(ite))];
        fnpi = [fn, '_pi'];
        fnllr = [fn, '_LLR'];
        disp(['Loading ' fn]);

        eval(['load ' fnpi]);
        disp('   eval hist for pi...');
        eval(['[nums, cens] = hist(' fnpi ', M);']);
        N = sum(nums);
        pi_pdfs(:, snr, ite) = nums' ./ (N * (cens(2) - cens(1)));
        pi_cens(:, snr, ite) = cens';
        disp('   eval variance...');
        eval(['pi_vars(snr, ite) = var(' fnpi ');']);
        disp('   eval mean...');
        eval(['pi_exps(snr, ite) = mean(' fnpi ');']);
        disp('   eval error...');
        eval(['pi_errs(snr, ite) = mean(' fnpi '<0);']);
        eval(['clear ' fnpi]);

        eval(['load ' fnllr]);
        disp('   eval hist for LLR...');
        eval(['[nums, cens] = hist(' fnllr ', M);']);
        N = sum(nums);
        llr_pdfs(:, snr, ite) = nums' ./ (N * (cens(2) - cens(1)));
        llr_cens(:, snr, ite) = cens';
        disp('   eval variance...');
        eval(['llr_vars(snr, ite) = var(' fnllr ');']);
        disp('   eval mean...');
        eval(['llr_exps(snr, ite) = mean(' fnllr ');']);
        disp('   eval error...');
        eval(['llr_errs(snr, ite) = mean(' fnllr '<0);']);
        eval(['clear ' fnllr]);
    end
end
fn = [prefix '_data'];
disp(['Saving ' fn]);
eval(['save ' fn ' iters snrs N '...
        'pi_cens pi_pdfs pi_errs pi_vars pi_exps ' ...
        'llr_cens llr_pdfs llr_errs llr_vars llr_exps']);
