function plotllr (fn, plot_snrs, area1, area2)
%PLOTLLR   Plot LLR, pi vs. Eb/N0
%
%   See also: CONVDATA, PLOTBER.

%   Ling Li, Caltech
%   05/28/2001

if nargin < 1,
    fn = 'bo_data';
end

% default values of iters & snrs. 
% maybe over-defined by loading fn
iters = [1, 2, 4, 6, 8, 12, 16];
snrs = (0:6) / 2;
N = 65496;

disp(['Loading ' fn]);
eval(['load ' fn]);

niters = length(iters);
if nargin < 2,
    plot_snrs = snrs;
else
    plot_snrs = intersect(snrs, plot_snrs);
    i = 1;
    for j = plot_snrs,
        idx = find(snrs == j);
        llr_cens(:, i, :) = llr_cens(:, idx, :);
        llr_pdfs(:, i, :) = llr_pdfs(:, idx, :);
        pi_cens(:, i, :) = pi_cens(:, idx, :);
        pi_pdfs(:, i, :) = pi_pdfs(:, idx, :);
        i = i + 1;
    end
end

llr_pdfs = 100 * llr_pdfs;
pi_pdfs = 100 * pi_pdfs;

if nargin < 3,
    llrmin = max(-15, floor(min(min(min(llr_cens)))));
    llrmax = min(250-175, ceil(max(max(max(llr_cens)))));
    pdfmax = ceil(max(max(max(llr_pdfs))));
    area1 = [llrmin, llrmax, 0, pdfmax];
end
if nargin < 4,
    pimin = max(-15, floor(min(min(min(pi_cens)))));
    pimax = min(150-105, ceil(max(max(max(pi_cens)))));
    pdfmax = ceil(max(max(max(pi_pdfs))));
    area2 = [pimin, pimax, 0, pdfmax];
end

idx = find(fn == '_');
fn(idx) = ' ';
psfn = fn(1:idx-1)

pos = 0;
for s = plot_snrs,
    idx = find(plot_snrs == s);
    
    pos = pos + 1;
%     if length(plot_snrs) > 3
%         subplot(3, 2, pos);
%     else
         figure;
%     end

    cmd = 'plot('; leg = 'legend(';
    for ite = 1:niters,
        if ite ~= 1,
            cmd = [cmd, ', '];
            leg = [leg, ', '];
        end
        cmd = [cmd 'llr_cens(:, idx, ' int2str(ite) ...
                '), llr_pdfs(:, idx, ' int2str(ite) ')'];
        leg = [leg '''iteration #' num2str(iters(ite)) ''''];
    end
    eval([cmd, ');']);
    if (pos == 1)
        eval([leg, ');']);
    end

%    title([fn ', E_b/N_0 = ' num2str(s) 'dB']);
    title(['E_b/N_0 = ' num2str(s) 'dB']);
    xlabel('LLR');
    ylabel('Probability density (%)');
    axis(area1);
    print(gcf, '-depsc', sprintf('%sllr%02d', psfn, s*10));
end

pos = 0;
for s = plot_snrs,
    idx = find(plot_snrs == s);
    
    pos = pos + 1;
%     if length(plot_snrs) > 3
%         subplot(3, 2, pos);
%     else
         figure;
%     end

    cmd = 'plot('; leg = 'legend(';
    for ite = 1:niters,
        if ite ~= 1,
            cmd = [cmd, ', '];
            leg = [leg, ', '];
        end
        cmd = [cmd 'pi_cens(:, idx, ' int2str(ite) ...
                '), pi_pdfs(:, idx, ' int2str(ite) ')'];
        leg = [leg '''iteration #' num2str(iters(ite)) ''''];
    end
    eval([cmd, ');']);
    if (pos == 1)
        eval([leg, ');']);
    end

%    title([fn ', E_b/N_0 = ' num2str(s) 'dB']);
    title(['E_b/N_0 = ' num2str(s) 'dB']);
    xlabel('\Lambda_2^{ext}');
    ylabel('Probability density (%)');
    axis(area2);
    print(gcf, '-depsc', sprintf('%sext%02d', psfn, s*10));
end
close all;
return;
i = 1;
    
figure; hold on;

area = cens(i, 1):0.1:cens(i, end);

plot(cens(i, :), nums(i, :));
plot(2*center(i) - cens(i, :), nums(i, :), 'r');
plot(area, 100 / sqrt(2 *pi*vars(i)) * exp(- (area - center(i)).^2 / 2 / vars(i)), 'k--');

%plot(-cens(i, :), exp(-cens(i,:)).*nums(i, :), 'c');

legend('LLR dist.', 'LLR mirror', 'Gaussian');
xlabel('LLR');
ylabel('Percentage (%)');
title(['E_b/N_0 = ' num2str((i+1)/2) 'dB']);
